@@ -129,7 +129,7 @@ class Model(NewBaseModel):
 
         if not self.pk and self.Meta.model_fields[self.Meta.pkname].autoincrement:
             self_fields.pop(self.Meta.pkname, None)
-        self_fields = self.objects._populate_default_values(self_fields)
+        self_fields = self.populate_default_values(self_fields)
         expr = self.Meta.table.insert()
         expr = expr.values(**self_fields)
         item_id = await self.Meta.database.execute(expr)
